Problem class
- Implementers
Constructors
- Problem()
Properties
- currentState ↔ State
-
getter/setter pair
- finalState ↔ State
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState ↔ State
-
getter/setter pair
- introduction ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentState(
) → State -
getFinalState(
) → State -
getInitialState(
) → State -
getIntroduction(
) → String -
getName(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentState(
State currentState) → void -
setFinalState(
State finalState) → void -
setInitialState(
State initialState) → void -
setIntroduction(
String introduction) → void -
setName(
String name) → void -
success(
) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited